calculate_info_edges: Calculate information contribution of edges

Description Usage Arguments Details Value Examples

View source: R/calculate_info_edges.R

Description

Calculate information contribution of edges

Usage

1
calculate_info_edges(x, block_size = 4, offset = 4)

Arguments

x

an igraph object or a valid adjacency matrix.

block_size

block size required to estimate the Kolmogorov-Chaitin complexity of x using the 2-dimensional Block Decomposition Method (BDM).

offset

offset required to estimate the Kolmogorov-Chaitin complexity of x using the 2-dimensional Block Decomposition Method (BDM).

Details

The information contribution of an edge e to a graph G is given by I(G,e)=C(G)-C(G-e), where C(G) denotes the information content of G and C(G-e) the information content of G after removing e. This function performs sequential perturbations (deletions) on the edges of G to calculate their information contribution.

Value

A data frame containing the perturbations on the original graph's edges, and their corresponding BDM values and estimated information contributions.

Examples

1
2
3
4
5
## Not run: 
coxeter_graph <- make_graph("Coxeter")
calculate_info_edges(coxeter_graph)

## End(Not run)

allgebrist/algodyn documentation built on Oct. 21, 2019, 2:47 a.m.