calculate_info_vertices: Calculate information contribution of vertices

Description Usage Arguments Details Value Examples

View source: R/calculate_info_vertices.R

Description

Calculate information contribution of vertices

Usage

1
calculate_info_vertices(x, block_size = 4, offset = 4)

Arguments

x

an igraph object or a valid adjacency matrix.

block_size

block size required to estimate the Kolmogorov-Chaitin complexity of x using the 2-dimensional Block Decomposition Method (BDM).

offset

offset required to estimate the Kolmogorov-Chaitin complexity of x using the 2-dimensional Block Decomposition Method (BDM).

Details

The information contribution of a vertex v to a graph G is given by I(G,v)=C(G)-C(G-v), where C(G) denotes the information content of G and C(G-v) the information content of G after removing v. This function performs sequential perturbations (deletions) on the vertices of G to calculate their information contribution.

Value

A data frame containing the perturbations on the original graph's vertices, and their corresponding BDM values and estimated information contributions.

Examples

1
2
3
4
5
## Not run: 
tutte_graph <- make_graph("Tutte")
calculate_info_vertices(tutte_graph)

## End(Not run)

allgebrist/algodyn documentation built on Oct. 21, 2019, 2:47 a.m.