relative_reprogrammability: Calculate Relative Reprogrammability

Description Usage Arguments Details Value Examples

View source: R/relative_reprogrammability.R

Description

Calculate Relative Reprogrammability

Usage

1
relative_reprogrammability(x, what, block_size = 4, offset = 4)

Arguments

x

an igraph object.

what

graph elements to be removed (i.e. edges or vertices).

block_size

block size required to estimate the Kolmogorov-Chaitin complexity of x using the 2-dimensional Block Decomposition Method (BDM).

offset

offset required to estimate the Kolmogorov-Chaitin complexity of x using the 2-dimensional Block Decomposition Method (BDM).

Details

The Relative Reprogrammability index measures the shape of a graph's information signature.

Value

A numeric corresponding to the Relative Reprogrammability index of the input graph.

Examples

1
2
3
4
5
## Not run: 
robertson_graph <- make_graph("Robertson")
relative_reprogrammability(robertson_graph, 'edges')

## End(Not run)

allgebrist/algodyn documentation built on Oct. 21, 2019, 2:47 a.m.