Description Usage Arguments Details Value Examples
View source: R/calculate_info_edges.R
Calculate information contribution of edges
1 | calculate_info_edges(x, block_size = 4, offset = 4)
|
x |
an igraph object or a valid adjacency matrix. |
block_size |
block size required to estimate the Kolmogorov-Chaitin complexity of |
offset |
offset required to estimate the Kolmogorov-Chaitin complexity of |
The information contribution of an edge e to a graph G is given by I(G,e)=C(G)-C(G-e), where C(G) denotes the information content of G and C(G-e) the information content of G after removing e. This function performs sequential perturbations (deletions) on the edges of G to calculate their information contribution.
A data frame containing the perturbations on the original graph's edges, and their corresponding BDM values and estimated information contributions.
1 2 3 4 5 | ## Not run:
coxeter_graph <- make_graph("Coxeter")
calculate_info_edges(coxeter_graph)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.