Description Usage Arguments Details Value Examples
View source: R/calculate_info_vertices.R
Calculate information contribution of vertices
1 | calculate_info_vertices(x, block_size = 4, offset = 4)
|
x |
an igraph object or a valid adjacency matrix. |
block_size |
block size required to estimate the Kolmogorov-Chaitin complexity of |
offset |
offset required to estimate the Kolmogorov-Chaitin complexity of |
The information contribution of a vertex v to a graph G is given by I(G,v)=C(G)-C(G-v), where C(G) denotes the information content of G and C(G-v) the information content of G after removing v. This function performs sequential perturbations (deletions) on the vertices of G to calculate their information contribution.
A data frame containing the perturbations on the original graph's vertices, and their corresponding BDM values and estimated information contributions.
1 2 3 4 5 | ## Not run:
tutte_graph <- make_graph("Tutte")
calculate_info_vertices(tutte_graph)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.