Description Usage Arguments Details Value Examples
View source: R/relative_reprogrammability.R
Calculate Relative Reprogrammability
1 | relative_reprogrammability(x, what, block_size = 4, offset = 4)
|
x |
an igraph object. |
what |
graph elements to be removed (i.e. edges or vertices). |
block_size |
block size required to estimate the Kolmogorov-Chaitin complexity of |
offset |
offset required to estimate the Kolmogorov-Chaitin complexity of |
The Relative Reprogrammability index measures the shape of a graph's information signature.
A numeric corresponding to the Relative Reprogrammability index of the input graph.
1 2 3 4 5 | ## Not run:
robertson_graph <- make_graph("Robertson")
relative_reprogrammability(robertson_graph, 'edges')
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.